@@ -142,7 +142,8 @@ class TaskAssignator:
                 coromask(
                     self.new_process,
                     args, {},
-                    simple_fargs_out)
+                    simple_fargs_out),
+                name="task_new_process"
             )
             #
             task.add_done_callback(
